@@ -45,6 +45,7 @@ ARCHIVE_URL_DICT = {
     'spotted_skunk_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.skunk_spotted.v0.zip',
     'humpback_dorsal': 'https://wildbookiarepository.azureedge.net/models/labeler.whale_humpback.dorsal.v0.zip',
     'orca_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.whale_orca.v0.zip',
+    'whale_sperm_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.whale_sperm.v0.zip',
     'fins_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.fins.v0.zip',
     'fins_v1': 'https://wildbookiarepository.azureedge.net/models/labeler.fins.v1.1.zip',
     'wilddog_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.wild_dog.v0.zip',
@@ -81,7 +82,9 @@ ARCHIVE_URL_DICT = {
     'grey_whale_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.whale_grey.v0.zip',
     'beluga_whale_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.whale_beluga.v0.zip',
     'beluga_whale_v1': 'https://wildbookiarepository.azureedge.net/models/labeler.whale_beluga.v1.zip',
+    'sea_turtle_v4': 'https://wildbookiarepository.azureedge.net/models/labeler.sea_turtle.v4.zip',
     'seals_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.seals.v0.zip',
+    'spotted_eagle_ray_v0': 'https://wildbookiarepository.azureedge.net/models/labeler.spotted_eagle_ray.v0.zip',
 }
 
 
@@ -92,10 +95,10 @@ if not ut.get_argflag('--no-pytorch'):
         import torch.optim as optim
         import torchvision
 
-        logger.info('PyTorch Version: ', torch.__version__)
-        logger.info('Torchvision Version: ', torchvision.__version__)
+        logger.info('PyTorch Version: %s' % (torch.__version__,))
+        logger.info('Torchvision Version: %s' % (torchvision.__version__,))
     except ImportError:
-        logger.info('WARNING Failed to import pytorch. ' 'PyTorch is unavailable')
+        logger.info('WARNING Failed to import pytorch.  PyTorch is unavailable')
         if ut.SUPER_STRICT:
             raise
 
