@@ -27,6 +27,9 @@ CONTAINER_NAME = ut.get_argval(
 ENGINE_SLOT = ut.get_argval('--engine-slot', type_=str, default='default')
 
 
+CODEX = ut.get_argval('--codex', type_=str, default='codex_houston_1')
+
+
 PI = math.pi
 TAU = 2.0 * PI
 
@@ -131,7 +134,7 @@ SEX_TEXT_TO_INT = ut.invert_dict(SEX_INT_TO_TEXT)
 
 
 class PATH_NAMES(object):  # NOQA
-    """ Path names for internal IBEIS database """
+    """Path names for internal IBEIS database"""
 
     sqldb = '_ibeis_database.sqlite3'
     sqlstaging = '_ibeis_staging.sqlite3'
@@ -158,7 +161,7 @@ class PATH_NAMES(object):  # NOQA
 
 
 class REL_PATHS(object):  # NOQA
-    """ all paths are relative to ibs.dbdir """
+    """all paths are relative to ibs.dbdir"""
 
     _ibsdb = PATH_NAMES._ibsdb
     trashdir = PATH_NAMES.trashdir
@@ -408,12 +411,14 @@ SPECIES_WITH_DETECTORS = (
     'seadragon_weedy+head',
     'skunk_spotted',
     'snow_leopard',
+    'spotted_eagle_ray',
     'turtle_green',
     'turtle_green+head',
     'turtle_hawksbill',
     'turtle_hawksbill+head',
     'turtle_oliveridley',
     'turtle_oliveridley+head',
+    'turtle_asian',
     'turtle_sea',
     'turtle_sea+head',
     'whale_fluke',
@@ -430,11 +435,11 @@ SPECIES_WITH_DETECTORS = (
     'wild_dog_puppy',
     'wild_dog_standard',
     'wild_dog_tan',
+    'dolphin_bottlenose+dorsal',
     'dolphin_bottlenose+fin_dorsal',
     'dolphin_spotted+fin_dorsal',
     'shark_sand_tiger+fin_dorsal_back',
     'shark_sand_tiger+fin_dorsal_front',
-    'whale_fin+fin_dorsal',
     'whale_humpback+fin_dorsal',
     'whale_humpback+fin_dorsal_back',
     'whale_humpback+fin_dorsal_front',
@@ -449,7 +454,12 @@ SPECIES_WITH_DETECTORS = (
     'grey_seal_pup',
     'harbour_seal',
     'hawaiian_monk_seal',
+    'whale_sperm',
+    'whale_sperm+fluke',
+    'yellow_bellied_toad',
     # Latin (Flukebook)
+    'aetobatus_narinari',
+    'bombina_variegata',
     'chelonioidea',
     'chelonioidea+head',
     'chelonia_mydas',
@@ -485,6 +495,8 @@ SPECIES_WITH_DETECTORS = (
     'stenella_frontalis',
     'stenella_frontalis+dorsal',
     'stenella_frontalis+fin_dorsal',
+    'tursiops_truncatus+dorsal',
+    'tursiops_truncatus+fin_dorsal',
     'orcinus_orca',
     'orcinus_orca+fin_dorsal',
     'panthera_pardus',
@@ -496,6 +508,8 @@ SPECIES_WITH_DETECTORS = (
     'phoca_vitulina',
     'halichoerus_grypus',
     'monachus_schauinslandi',
+    'physeter_macrocephalus',
+    'physeter_macrocephalus+fluke',
 )
 
 
@@ -573,8 +587,10 @@ SPECIES_MAPPING = {
     'tiger': ('TIGER', 'Tiger'),
     'turtle_sea': ('ST', 'Sea Turtle (Generic)'),
     'turtle_sea_generic': (None, 'turtle_sea'),
-    'turtle_hawksbill': ('STHB', 'Sea Turtle (Hawksbill)'),
-    'turtle_green': ('STG', 'Sea Turtle (Green)'),
+    'turtle_green': ('ST-G', 'Sea Turtle (Green)'),
+    'turtle_hawksbill': ('ST-HB', 'Sea Turtle (Hawksbill)'),
+    'turtle_oliveridley': ('ST-OR', 'Sea Turtle (Olive Ridley)'),
+    'turtle_asian': ('ST-A', 'Sea Turtle (Asian)'),
     'train': ('TRAIN', 'Train'),
     'truck': ('TRUCK', 'Truck'),
     'toads_wyoming': ('WYTOAD', 'Toad (Wyoming)'),
@@ -588,16 +604,16 @@ SPECIES_MAPPING = {
     'wild_dog_tan': ('WDT', 'Wild Dog Tan'),
     'wild_dog_puppy': ('WDP', 'Wild Dog Puppy'),
     'wild_dog_standard': ('WDS', 'Wild Dog Standard'),
-    'wild_dog+tail_general': ('WD+GEN', 'Wild Dog Tail General'),
-    'wild_dog+tail_multi_black': ('WD+MB', 'Wild Dog Tail Multi-Black'),
-    'wild_dog+tail_long_black': ('WD+LB', 'Wild Dog Tail Long Black'),
-    'wild_dog+tail_long_white': ('WD+LW', 'Wild Dog Tail Long White'),
-    'wild_dog+tail_long': ('WD+LONG', 'Wild Dog Tail Long'),
-    'wild_dog+tail_double_black_brown': ('WD+DBB', 'Wild Dog Tail Double Black Brown'),
-    'wild_dog+tail_double_black_white': ('WD+DBW', 'Wild Dog Tail Double Black White'),
-    'wild_dog+tail_triple_black': ('WD+TB', 'Wild Dog Tail Triple Black'),
-    'wild_dog+tail_short_black': ('WD+SB', 'Wild Dog Tail Short Black'),
-    'wild_dog+tail_standard': ('WD+STD', 'Wild Dog Tail Standard'),
+    # 'wild_dog+tail_general': ('WD+GEN', 'Wild Dog Tail General'),
+    # 'wild_dog+tail_multi_black': ('WD+MB', 'Wild Dog Tail Multi-Black'),
+    # 'wild_dog+tail_long_black': ('WD+LB', 'Wild Dog Tail Long Black'),
+    # 'wild_dog+tail_long_white': ('WD+LW', 'Wild Dog Tail Long White'),
+    # 'wild_dog+tail_long': ('WD+LONG', 'Wild Dog Tail Long'),
+    # 'wild_dog+tail_double_black_brown': ('WD+DBB', 'Wild Dog Tail Double Black Brown'),
+    # 'wild_dog+tail_double_black_white': ('WD+DBW', 'Wild Dog Tail Double Black White'),
+    # 'wild_dog+tail_triple_black': ('WD+TB', 'Wild Dog Tail Triple Black'),
+    # 'wild_dog+tail_short_black': ('WD+SB', 'Wild Dog Tail Short Black'),
+    # 'wild_dog+tail_standard': ('WD+STD', 'Wild Dog Tail Standard'),
     'wild_dog': ('WD', 'Wild Dog'),
     'whale_fluke': ('WF', 'Whale Fluke'),
     'whale_beluga': ('BW', 'Beluga Whale'),
@@ -611,15 +627,25 @@ SPECIES_MAPPING = {
 }
 
 PARTS_MAPPING = {
-    'head': 'Head',
-    'standard': 'Standard Tail',
-    'short_black': 'Short Black Tail',
-    'long_black': 'Long Black Tail',
-    'double_black_brown': 'Double Black Brown Tail',
-    'double_black_white': 'Double Black White Tail',
-    'triple_black': 'Triple Black Tail',
-    'long_white': 'Long White Tail',
-    UNKNOWN: 'UNSPECIFIED,',
+    '+head': ('+H', 'Head'),
+    # 'standard': ('Standard Tail'),
+    # 'short_black': ('Short Black Tail'),
+    # 'long_black': ('Long Black Tail'),
+    # 'double_black_brown': ('Double Black Brown Tail'),
+    # 'double_black_white': ('Double Black White Tail'),
+    # 'triple_black': ('Triple Black Tail'),
+    # 'long_white': ('Long White Tail'),
+    '+tail_general': ('+GEN', 'Tail General'),
+    '+tail_multi_black': ('+MB', 'Tail Multi-Black'),
+    '+tail_long_black': ('+LB', 'Tail Long Black'),
+    '+tail_long_white': ('+LW', 'Tail Long White'),
+    '+tail_long': ('+LONG', 'Tail Long'),
+    '+tail_double_black_brown': ('+DBB', 'Tail Double Black Brown'),
+    '+tail_double_black_white': ('+DBW', 'Tail Double Black White'),
+    '+tail_triple_black': ('+TB', 'Tail Triple Black'),
+    '+tail_short_black': ('+SB', 'Tail Short Black'),
+    '+tail_standard': ('+STD', 'Tail Standard'),
+    UNKNOWN: ('+?', 'UNSPECIFIED'),
 }
 
 
