@@ -301,7 +301,9 @@ class WebMultipleNamedDuplicateException(WebException):
         message = (
             'Duplcate UUIDs are specified with more than one name:\n'
             'bad_database_uuids=%s\n'
-        ) % (ut.repr3(bad_dict, nl=1),)
+        ) % (
+            ut.repr3(bad_dict, nl=1),
+        )
         bad_dict = {str(k): v for k, v in bad_dict.items()}
         rawreturn = {
             'bad_dict': bad_dict,
@@ -730,7 +732,7 @@ def authentication_hash_only(func):
 
 
 def authentication_either(func):
-    """ authenticated by either hash or user """
+    """authenticated by either hash or user"""
 
     @wraps(func)
     def wrp_authentication_either(*args, **kwargs):
@@ -1344,7 +1346,7 @@ def make_ibs_register_decorator(modname):
     # INJECTED_MODULES.append(sys.modules[modname])
 
     def register_ibs_method(func):
-        """ registers autogenerated functions with the utool class method injector """
+        """registers autogenerated functions with the utool class method injector"""
         # func  = profile(func)
         register_ibs_unaliased_method(func)
         # aliastup = (func, '_injected_' + ut.get_funcname(func))
