@@ -1285,7 +1285,7 @@ def get_images(ibs, gid_list, ignore_orient=False, **kwargs):
 @register_ibs_method
 @accessor_decors.getter_1to1
 def get_image_imgdata(ibs, gid_list, ignore_orient=False, **kwargs):
-    """ alias for get_images with standardized name """
+    """alias for get_images with standardized name"""
     return get_images(ibs, gid_list, ignore_orient=ignore_orient, **kwargs)
 
 
@@ -1419,7 +1419,7 @@ def get_image_uuids(ibs, gid_list):
             UUID('0cd05978-3d83-b2ee-2ac9-798dd571c3b3'),
             UUID('0a9bc03d-a75e-8d14-0153-e2949502aba7'),
             UUID('2deeff06-5546-c752-15dc-2bd0fdb1198a'),
-            UUID('a9b70278-a936-c1dd-8a3b-bc1e9a998bf0'),
+            UUID('68ca272d-26f7-1dbb-76e9-08d192c1a4a7'),
             UUID('42fdad98-369a-2cbc-67b1-983d6d6a3a60'),
             UUID('c459d381-fd74-1d99-6215-e42e3f432ea9'),
             UUID('33fd9813-3a2b-774b-3fcc-4360d1ae151b'),
@@ -1891,7 +1891,7 @@ def get_image_unixtime_asfloat(ibs, gid_list, **kwargs):
 @accessor_decors.getter_1to1
 @register_api('/api/image/unixtime2/', methods=['GET'])
 def get_image_unixtime2(ibs, gid_list, **kwargs):
-    """ alias for get_image_unixtime_asfloat """
+    """alias for get_image_unixtime_asfloat"""
     return ibs.get_image_unixtime_asfloat(gid_list, **kwargs)
 
 
