@@ -5,7 +5,6 @@ controller functions for contributors, versions, configs, and other metadata
 import logging
 import functools
 import utool as ut
-from six.moves import range, input, zip
 from wbia import constants as const
 from wbia.control import accessor_decors, controller_inject
 from wbia.algo import Config
@@ -900,13 +899,12 @@ def get_metadata_value(ibs, metadata_key_list, db):
         URL:    /api/metadata/value/
     """
     params_iter = ((metadata_key,) for metadata_key in metadata_key_list)
-    where_clause = 'metadata_key=?'
     # list of relationships for each image
-    metadata_value_list = db.get_where(
+    metadata_value_list = db.get_where_eq(
         const.METADATA_TABLE,
         ('metadata_value',),
         params_iter,
-        where_clause,
+        ('metadata_key',),
         unpack_scalars=True,
     )
     return metadata_value_list
@@ -924,18 +922,31 @@ def get_metadata_rowid_from_metadata_key(ibs, metadata_key_list, db):
     """
     db = db[0]  # Unwrap tuple, required by @accessor_decors.getter_1to1 decorator
     params_iter = ((metadata_key,) for metadata_key in metadata_key_list)
-    where_clause = 'metadata_key=?'
     # list of relationships for each image
-    metadata_rowid_list = db.get_where(
+    metadata_rowid_list = db.get_where_eq(
         const.METADATA_TABLE,
         ('metadata_rowid',),
         params_iter,
-        where_clause,
+        ('metadata_key',),
         unpack_scalars=True,
     )
     return metadata_rowid_list
 
 
+@register_api('/api/version/', methods=['GET'])
+def get_version(ibs):
+    r"""
+    Returns the version of wbia
+
+    RESTful
+        Method: GET
+        URL:    /api/version/
+    """
+    from wbia._version import __version__
+
+    return {'version': __version__}
+
+
 @register_api('/api/core/version/', methods=['GET'])
 def get_database_version_alias(ibs, db=None):
     r"""
@@ -1010,15 +1021,14 @@ def _init_config(ibs):
     config_fpath = ut.unixjoin(ibs.get_dbdir(), 'general_config.cPkl')
     try:
         general_config = ut.load_cPkl(config_fpath, verbose=ut.VERBOSE)
-    except IOError as ex:
-        if ut.VERBOSE:
-            ut.printex(ex, 'failed to genral load config', iswarning=True)
-        general_config = {}
-    current_species = general_config.get('current_species', None)
-    if ut.VERBOSE and ut.NOT_QUIET:
-        logger.info(
-            '[_init_config] general_config.current_species = %r' % (current_species,)
+    except (FileNotFoundError, IOError):
+        logger.warning(
+            'failed to load general config %r, creating empty config' % (config_fpath,)
         )
+        general_config = {}
+        ut.save_cPkl(config_fpath, general_config, verbose=ut.VERBOSE)
+    current_species = general_config.get('current_species', None)
+    logger.info('[_init_config] general_config.current_species = %r' % (current_species,))
     # </GENERAL CONFIG>
     #####
     # species_list = ibs.get_database_species()
