@@ -6,8 +6,7 @@ sh Tgen.sh --key review --invert --Tcfg with_getters=True with_setters=False --m
 # TODO: Fix this name it is too special case
 """
 import logging
-import six  # NOQA
-from six.moves import zip, map, reduce
+from functools import reduce
 
 # import numpy as np
 # import vtool as vt
@@ -57,24 +56,25 @@ def hack_create_aidpair_index(ibs):
         CREATE INDEX IF NOT EXISTS {index_name} ON {table} ({index_cols});
         """
     )
-    sqlcmd = sqlfmt.format(
-        index_name='aidpair_to_rowid',
-        table=ibs.const.REVIEW_TABLE,
-        index_cols=','.join([REVIEW_AID1, REVIEW_AID2]),
-    )
-    ibs.staging.connection.execute(sqlcmd).fetchall()
-    sqlcmd = sqlfmt.format(
-        index_name='aid1_to_rowids',
-        table=ibs.const.REVIEW_TABLE,
-        index_cols=','.join([REVIEW_AID1]),
-    )
-    ibs.staging.connection.execute(sqlcmd).fetchall()
-    sqlcmd = sqlfmt.format(
-        index_name='aid2_to_rowids',
-        table=ibs.const.REVIEW_TABLE,
-        index_cols=','.join([REVIEW_AID2]),
-    )
-    ibs.staging.connection.execute(sqlcmd).fetchall()
+    with ibs.staging.connect() as conn:
+        sqlcmd = sqlfmt.format(
+            index_name='aidpair_to_rowid',
+            table=ibs.const.REVIEW_TABLE,
+            index_cols=','.join([REVIEW_AID1, REVIEW_AID2]),
+        )
+        conn.execute(sqlcmd)
+        sqlcmd = sqlfmt.format(
+            index_name='aid1_to_rowids',
+            table=ibs.const.REVIEW_TABLE,
+            index_cols=','.join([REVIEW_AID1]),
+        )
+        conn.execute(sqlcmd)
+        sqlcmd = sqlfmt.format(
+            index_name='aid2_to_rowids',
+            table=ibs.const.REVIEW_TABLE,
+            index_cols=','.join([REVIEW_AID2]),
+        )
+        conn.execute(sqlcmd)
 
 
 @register_ibs_method
@@ -102,6 +102,13 @@ def _set_review_uuids(ibs, review_rowid_list, review_uuid_list):
     ibs.staging.set(const.REVIEW_TABLE, (REVIEW_UUID,), val_iter, id_iter)
 
 
+@register_ibs_method
+def _set_review_user_confidence(ibs, review_rowid_list, user_confidence_list):
+    id_iter = ((review_rowid,) for review_rowid in review_rowid_list)
+    val_iter = ((user_confidence,) for user_confidence in user_confidence_list)
+    ibs.staging.set(const.REVIEW_TABLE, (REVIEW_USER_CONFIDENCE,), val_iter, id_iter)
+
+
 @register_ibs_method
 def get_review_rowid_from_superkey(
     ibs, aid_1_list, aid_2_list, count_list, eager=False, nInput=None
@@ -386,7 +393,7 @@ def get_review_rowids_from_aid_tuple(
 
 
 @register_ibs_method
-def get_review_rowids_between(ibs, aids1, aids2=None, method=None):
+def get_review_rowids_between(ibs, aids1, aids2=None, method=1):
     """
     Find staging rowids between sets of aids
 
@@ -566,9 +573,8 @@ def get_review_decisions_from_only(ibs, aid_list, eager=True, nInput=None):
         REVIEW_EVIDENCE_DECISION,
     )
     params_iter = [(aid,) for aid in aid_list]
-    where_clause = '%s=?' % (REVIEW_AID1)
-    review_tuple_decisions_list = ibs.staging.get_where(
-        const.REVIEW_TABLE, colnames, params_iter, where_clause, unpack_scalars=False
+    review_tuple_decisions_list = ibs.staging.get_where_eq(
+        const.REVIEW_TABLE, colnames, params_iter, (REVIEW_AID1,), unpack_scalars=False
     )
     return review_tuple_decisions_list
 
@@ -586,9 +592,8 @@ def get_review_rowids_from_only(ibs, aid_list, eager=True, nInput=None):
     """
     colnames = (REVIEW_ROWID,)
     params_iter = [(aid,) for aid in aid_list]
-    where_clause = '%s=?' % (REVIEW_AID1)
-    review_rowids = ibs.staging.get_where(
-        const.REVIEW_TABLE, colnames, params_iter, where_clause, unpack_scalars=False
+    review_rowids = ibs.staging.get_where_eq(
+        const.REVIEW_TABLE, colnames, params_iter, (REVIEW_AID1,), unpack_scalars=False
     )
     return review_rowids
 
@@ -612,12 +617,11 @@ def get_review_rowids_from_single(ibs, aid_list, eager=True, nInput=None):
 def get_review_rowids_from_aid1(ibs, aid_list, eager=True, nInput=None):
     colnames = (REVIEW_ROWID,)
     params_iter = [(aid,) for aid in aid_list]
-    where_clause = '%s=?' % (REVIEW_AID1,)
-    review_rowids = ibs.staging.get_where(
+    review_rowids = ibs.staging.get_where_eq(
         const.REVIEW_TABLE,
         colnames,
         params_iter,
-        where_clause=where_clause,
+        (REVIEW_AID1,),
         unpack_scalars=False,
     )
     return review_rowids
@@ -627,12 +631,11 @@ def get_review_rowids_from_aid1(ibs, aid_list, eager=True, nInput=None):
 def get_review_rowids_from_aid2(ibs, aid_list, eager=True, nInput=None):
     colnames = (REVIEW_ROWID,)
     params_iter = [(aid,) for aid in aid_list]
-    where_clause = '%s=?' % (REVIEW_AID2,)
-    review_rowids = ibs.staging.get_where(
+    review_rowids = ibs.staging.get_where_eq(
         const.REVIEW_TABLE,
         colnames,
         params_iter,
-        where_clause=where_clause,
+        (REVIEW_AID2,),
         unpack_scalars=False,
     )
     return review_rowids
