@@ -69,6 +69,7 @@ def merge_databases(ibs_src, ibs_dst, rowid_subsets=None, localize_images=True):
     Example:
         >>> # ENABLE_DOCTEST
         >>> from wbia.dbio.export_subset import *  # NOQA
+        >>> from wbia.init.sysres import get_workdir
         >>> import wbia
         >>> db1 = ut.get_argval('--db1', str, default=None)
         >>> db2 = ut.get_argval('--db2', str, default=None)
@@ -77,18 +78,18 @@ def merge_databases(ibs_src, ibs_dst, rowid_subsets=None, localize_images=True):
         >>> delete_ibsdir = False
         >>> # Check for test mode instead of script mode
         >>> if db1 is None and db2 is None and dbdir1 is None and dbdir2 is None:
-        ...     db1 = 'testdb1'
-        ...     dbdir2 = 'testdb_dst'
+        ...     dbdir1 = '/'.join([get_workdir(), 'testdb1'])
+        ...     dbdir2 = '/'.join([get_workdir(), 'testdb_dst'])
         ...     delete_ibsdir = True
         >>> # Open the source and destination database
         >>> assert db1 is not None or dbdir1 is not None
         >>> assert db2 is not None or dbdir2 is not None
         >>> ibs_src = wbia.opendb(db=db1, dbdir=dbdir1)
         >>> ibs_dst = wbia.opendb(db=db2, dbdir=dbdir2, allow_newdir=True,
-        >>>                        delete_ibsdir=delete_ibsdir)
+        ...                       delete_ibsdir=delete_ibsdir)
         >>> merge_databases(ibs_src, ibs_dst)
         >>> check_merge(ibs_src, ibs_dst)
-        >>> ibs_dst.print_dbinfo()
+        >>> # ibs_dst.print_dbinfo()
     """
     # TODO: ensure images are localized
     # otherwise this wont work
@@ -103,12 +104,13 @@ def merge_databases(ibs_src, ibs_dst, rowid_subsets=None, localize_images=True):
     ibs_dst.ensure_contributor_rowids()
     ibs_src.fix_invalid_annotmatches()
     ibs_dst.fix_invalid_annotmatches()
+
     # Hack move of the external data
     if rowid_subsets is not None and const.IMAGE_TABLE in rowid_subsets:
-        gid_list = rowid_subsets[const.IMAGE_TABLE]
+        src_gid_list = rowid_subsets[const.IMAGE_TABLE]
     else:
-        gid_list = ibs_src.get_valid_gids()
-    imgpath_list = ibs_src.get_image_paths(gid_list)
+        src_gid_list = ibs_src.get_valid_gids()
+    imgpath_list = ibs_src.get_image_paths(src_gid_list)
     dst_imgdir = ibs_dst.get_imgdir()
     if localize_images:
         ut.copy_files_to(imgpath_list, dst_imgdir, overwrite=False, verbose=True)
@@ -133,6 +135,60 @@ def merge_databases(ibs_src, ibs_dst, rowid_subsets=None, localize_images=True):
     ibs_dst.db.merge_databases_new(
         ibs_src.db, ignore_tables=ignore_tables, rowid_subsets=rowid_subsets
     )
+
+    # Add ImageSets
+    blacklist_set = set(
+        [
+            'Reviewed Images',
+            'Exemplars',
+            '*Exemplars',
+            'All Images',
+            '*All Images',
+            '*Undetected Images',
+            '*Ungrouped Images',
+        ]
+    )
+
+    imageset_dict = {}
+    src_guuids = ibs_src.get_image_uuids(src_gid_list)
+    src_texts_list = ibs_src.get_image_imagesettext(src_gid_list)
+
+    for src_guuid, src_text_list in zip(src_guuids, src_texts_list):
+        current_set = imageset_dict.get(src_guuid, set([]))
+        src_text_set = set(src_text_list) - blacklist_set
+        src_text_set_ = set([])
+        for src_text in src_text_set:
+            src_text_ = '%s / %s' % (
+                ibs_src.dbname,
+                src_text,
+            )
+            src_text_set_.add(src_text_)
+        src_text_set = src_text_set_ | current_set
+        imageset_dict[src_guuid] = src_text_set
+
+    # Set all imagesets for merged databases
+    dst_guuids = list(imageset_dict.keys())
+    dst_gid_list = ibs_dst.get_image_gids_from_uuid(dst_guuids)
+    assert None not in dst_gid_list
+    dst_text_set_list = [list(imageset_dict[dst_guuid]) for dst_guuid in dst_guuids]
+    length_list = map(len, dst_text_set_list)
+    zipped = zip(dst_gid_list, length_list)
+    dst_gid_list = ut.flatten([[dst_gid] * length for dst_gid, length in zipped])
+    dst_text_list = ut.flatten(dst_text_set_list)
+    assert len(dst_gid_list) == len(dst_text_list)
+    ibs_dst.set_image_imagesettext(dst_gid_list, dst_text_list)
+
+    # Add imageset for Import
+    src_image_uuids = ibs_src.get_image_uuids(src_gid_list)
+    dst_gid_list = ibs_dst.get_image_gids_from_uuid(src_image_uuids)
+    assert None not in dst_gid_list
+    timestamp = ut.timestamp(format_='printable').split()[1]
+    imageset_text = 'Import from %s on %s' % (
+        ibs_src.dbname,
+        timestamp,
+    )
+    ibs_dst.set_image_imagesettext(dst_gid_list, [imageset_text] * len(dst_gid_list))
+
     logger.info(
         'FINISHED MERGE %r into %r' % (ibs_src.get_dbname(), ibs_dst.get_dbname())
     )
@@ -1013,7 +1069,7 @@ def check_database_overlap(ibs1, ibs2):
         >>> import wbia
         >>> import utool as ut
         >>> #ibs1 = wbia.opendb(db='PZ_Master0')
-        >>> #ibs2 = wbia.opendb(dbdir='/raid/work2/Turk/PZ_Master')
+        >>> #ibs2 = wbia.opendb(dbdir='/raid/work2/PZ_Master')
         >>> db1 = ut.get_argval('--db1', str, default='PZ_MTEST')
         >>> db2 = ut.get_argval('--db2', str, default='testdb1')
         >>> dbdir1 = ut.get_argval('--dbdir1', str, default=None)
