@@ -10,7 +10,6 @@ TODO: need to split up into sub modules:
     within this file
 """
 import logging
-from six.moves import zip
 from os.path import exists, expanduser, join, abspath
 import numpy as np
 import vtool as vt
@@ -333,7 +332,7 @@ def export_to_coco(
     use_existing_train_test=True,
     include_parts=False,
     gid_list=None,
-    include_reviews=True,
+    include_reviews=False,
     require_image_reviewed=False,
     require_named=False,
     output_images=True,
