@@ -3,7 +3,6 @@
 Unfinished non-wbia dependent version of interact matches
 """
 import utool as ut
-import six
 import numpy as np
 from wbia.plottool import abstract_interaction
 
@@ -12,7 +11,7 @@ BASE_CLASS = abstract_interaction.AbstractInteraction
 
 # TODO: move to plottool and decouple with IBEIS
 # TODO: abstract interaction
-@six.add_metaclass(ut.ReloadingMetaclass)
+@ut.reloadable_class
 class MatchInteraction2(BASE_CLASS):
     """
     TODO: replace functional version with this class
