@@ -59,103 +59,6 @@ def sight_resight_prob(N_range, nvisit1, nvisit2, resight):
     return probs
 
 
-def sight_resight_count(nvisit1, nvisit2, resight):
-    r"""
-    Lincoln Petersen Index
-
-    The Lincoln-Peterson index is a method used to estimate the total number of
-    individuals in a population given two independent sets observations.  The
-    likelihood of a population size is a hypergeometric distribution given by
-    assuming a uniform sampling distribution.
-
-    Args:
-        nvisit1 (int): the number of individuals seen on visit 1.
-        nvisit2 (int): be the number of individuals seen on visit 2.
-        resight (int): the number of (matched) individuals seen on both visits.
-
-    Returns:
-        tuple: (pl_index, pl_error)
-
-    LaTeX:
-        \begin{equation}\label{eqn:lpifull}
-            L(\poptotal \given \nvisit_1, \nvisit_2, \resight) =
-            \frac{
-                \binom{\nvisit_1}{\resight}
-                \binom{\poptotal - \nvisit_1}{\nvisit_2 - \resight}
-            }{
-                \binom{\poptotal}{\nvisit_2}
-            }
-        \end{equation}
-        Assuming that $T$ has a uniform prior distribution, the maximum
-          likelihood estimation of population size given two visits to a
-          location is:
-        \begin{equation}\label{eqn:lpi}
-            \poptotal \approx
-            \frac{\nvisit_1 \nvisit_2}{\resight} \pm 1.96 \sqrt{\frac{{(\nvisit_1)}^2 (\nvisit_2) (\nvisit_2 - \resight)}{\resight^3}}
-        \end{equation}
-
-    References:
-        https://en.wikipedia.org/wiki/Mark_and_recapture
-        https://en.wikipedia.org/wiki/Talk:Mark_and_recapture#Statistical_treatment
-        https://mail.google.com/mail/u/0/#search/lincoln+peterse+n/14c6b50227f5209f
-        https://probabilityandstats.wordpress.com/tag/maximum-likelihood-estimate/
-        http://math.arizona.edu/~jwatkins/o-mle.pdf
-
-    CommandLine:
-        python -m wbia.other.dbinfo sight_resight_count --show
-
-    Example:
-        >>> # DISABLE_DOCTEST
-        >>> from wbia.other.dbinfo import *  # NOQA
-        >>> nvisit1 = 100
-        >>> nvisit2 = 20
-        >>> resight = 10
-        >>> (pl_index, pl_error) = sight_resight_count(nvisit1, nvisit2, resight)
-        >>> result = '(pl_index, pl_error) = %s' % ut.repr2((pl_index, pl_error))
-        >>> pl_low = max(pl_index - pl_error, 1)
-        >>> pl_high = pl_index + pl_error
-        >>> print('pl_low = %r' % (pl_low,))
-        >>> print('pl_high = %r' % (pl_high,))
-        >>> print(result)
-        >>> ut.quit_if_noshow()
-        >>> import wbia.plottool as pt
-        >>> import scipy, scipy.stats
-        >>> x = pl_index  # np.array([10, 11, 12])
-        >>> k, N, K, n = resight, x, nvisit1, nvisit2
-        >>> #k, M, n, N = k, N, k, n  # Wiki to SciPy notation
-        >>> #prob = scipy.stats.hypergeom.cdf(k, N, K, n)
-        >>> fig = pt.figure(1)
-        >>> fig.clf()
-        >>> N_range = np.arange(1, pl_high * 2)
-        >>> # Something seems to be off
-        >>> probs = sight_resight_prob(N_range, nvisit1, nvisit2, resight)
-        >>> pl_prob = sight_resight_prob([pl_index], nvisit1, nvisit2, resight)[0]
-        >>> pt.plot(N_range, probs, 'b-', label='probability of population size')
-        >>> pt.plt.title('nvisit1=%r, nvisit2=%r, resight=%r' % (
-        >>>     nvisit1, nvisit2, resight))
-        >>> pt.plot(pl_index, pl_prob, 'rx', label='Lincoln Peterson Estimate')
-        >>> pt.plot([pl_low, pl_high], [pl_prob, pl_prob], 'gx-',
-        >>>         label='Lincoln Peterson Error Bar')
-        >>> pt.legend()
-        >>> ut.show_if_requested()
-    """
-    import math
-
-    try:
-        nvisit1 = float(nvisit1)
-        nvisit2 = float(nvisit2)
-        resight = float(resight)
-        pl_index = int(math.ceil((nvisit1 * nvisit2) / resight))
-        pl_error_num = float((nvisit1 ** 2) * nvisit2 * (nvisit2 - resight))
-        pl_error_dom = float(resight ** 3)
-        pl_error = int(math.ceil(1.96 * math.sqrt(pl_error_num / pl_error_dom)))
-    except ZeroDivisionError:
-        # pl_index = 'Undefined - Zero recaptured (k = 0)'
-        pl_index = 0
-        pl_error = 0
-    return pl_index, pl_error
-
-
 def dans_splits(ibs):
     """
     python -m wbia dans_splits --show
