@@ -6,13 +6,12 @@ import logging
 import numpy as np
 import utool as ut
 import vtool as vt  # NOQA
-import six
 
 print, rrr, profile = ut.inject2(__name__)
 logger = logging.getLogger('wbia')
 
 
-@six.add_metaclass(ut.ReloadingMetaclass)
+@ut.reloadable_class
 class OrigAnnotInference(object):
     """
     Make name inferences about a series of AnnotMatches
@@ -123,8 +122,12 @@ class OrigAnnotInference(object):
         aid2_aidx = ut.make_index_lookup(unique_aids)
         prob_annots = np.zeros((len(unique_aids), len(unique_aids)))
         for count, cm in enumerate(cm_list):
+            aid2_annot_score = {}
+            for aid, aidx in aid2_aidx.items():
+                aid2_annot_score[aid] = cm.annot_score_list[aidx]
+
             idx = aid2_aidx[cm.qaid]
-            annot_scores = ut.dict_take(cm.aid2_annot_score, unique_aids, 0)
+            annot_scores = ut.dict_take(aid2_annot_score, unique_aids, 0)
             prob_annots[idx][:] = annot_scores
         prob_annots[np.diag_indices(len(prob_annots))] = np.inf
         prob_annots += 1e-9
@@ -142,7 +145,10 @@ class OrigAnnotInference(object):
         prob_names = np.zeros((len(cm_list), len(unique_nids)))
         for count, cm in enumerate(cm_list):
             try:
-                name_scores = ut.dict_take(cm.nid2_name_score, unique_nids, 0)
+                nid2_name_score = {}
+                for nid, nidx in cm.nid2_nidx.items():
+                    nid2_name_score[nid] = cm.name_score_list[nidx]
+                name_scores = ut.dict_take(nid2_name_score, unique_nids, 0)
             except AttributeError:
                 unique_nidxs = ut.take(cm.nid2_nidx, unique_nids)
                 name_scores = ut.take(cm.name_score_list, unique_nidxs)
@@ -337,34 +343,38 @@ class OrigAnnotInference(object):
             error_flag = ut.compress(strflags, [split_case, merge_case, new_name])
             # error_flag = split_case or merge_case
 
-            # <HACK>
-            # SET EXEMPLARS
-            ibs = self.qreq_.ibs
-            viewpoint_texts = ibs.get_annot_yaw_texts(aids)
-            view_to_aids = ut.group_items(aids, viewpoint_texts)
-            num_wanted_exemplars_per_view = 4
-            hack_set_these_qaids_as_exemplars = set([])
-            for view, aids_ in view_to_aids.items():
-                heuristic_exemplar_aids = set(aids) - qaid_set
-                heuristic_non_exemplar_aids = set(aids).intersection(qaid_set)
-                num_needed_exemplars = num_wanted_exemplars_per_view - len(
-                    heuristic_exemplar_aids
-                )
-                # Choose the best query annots to fill out exemplars
-                if len(heuristic_non_exemplar_aids) == 0:
-                    continue
-                quality_ints = ibs.get_annot_qualities(heuristic_non_exemplar_aids)
-                okish = ibs.const.QUALITY_TEXT_TO_INT[ibs.const.QUAL_OK] - 0.1
-                quality_ints = [x if x is None else okish for x in quality_ints]
-                aids_ = ut.sortedby(heuristic_non_exemplar_aids, quality_ints)[::-1]
-                chosen = aids_[:num_needed_exemplars]
-                for qaid_ in chosen:
-                    hack_set_these_qaids_as_exemplars.add(qaid_)
-            # </HACK>
+            if True:
+                # <HACK>
+                # SET EXEMPLARS
+                ibs = self.qreq_.ibs
+                viewpoint_texts = ibs.get_annot_yaw_texts(aids)
+                view_to_aids = ut.group_items(aids, viewpoint_texts)
+                num_wanted_exemplars_per_view = 4
+                hack_set_these_qaids_as_exemplars = set([])
+                for view, aids_ in view_to_aids.items():
+                    heuristic_exemplar_aids = set(aids) - qaid_set
+                    heuristic_non_exemplar_aids = set(aids).intersection(qaid_set)
+                    num_needed_exemplars = num_wanted_exemplars_per_view - len(
+                        heuristic_exemplar_aids
+                    )
+                    # Choose the best query annots to fill out exemplars
+                    if len(heuristic_non_exemplar_aids) == 0:
+                        continue
+                    quality_ints = ibs.get_annot_qualities(heuristic_non_exemplar_aids)
+                    okish = ibs.const.QUALITY_TEXT_TO_INT[ibs.const.QUAL_OK] - 0.1
+                    quality_ints = [x if x is None else okish for x in quality_ints]
+                    aids_ = ut.sortedby(heuristic_non_exemplar_aids, quality_ints)[::-1]
+                    chosen = aids_[:num_needed_exemplars]
+                    for qaid_ in chosen:
+                        hack_set_these_qaids_as_exemplars.add(qaid_)
+                # </HACK>
+            else:
+                hack_set_these_qaids_as_exemplars = set(aids)
+
             if not error_flag and not new_name:
                 new_nid = nids[0]
             else:
-                new_nid = six.next(next_new_nid)
+                new_nid = next(next_new_nid)
             for aid in aids:
                 if aid not in qaid_set:
                     if len(error_flag) == 0:
