@@ -41,11 +41,14 @@ def get_query_annot_pair_info(
             'curvrankdorsal',
             'curvrankfinfindrhybriddorsal',
             'curvrankfluke',
+            'curvranktwodorsal',
+            'curvranktwofluke',
             'deepsense',
             'finfindr',
             'kaggle7',
             'kaggleseven',
             'pie',
+            'pietwo',
         ]
     ) and getattr(qreq_, '_isnewreq', None):
         if (
@@ -86,11 +89,14 @@ def get_data_annot_pair_info(
             'curvrankdorsal',
             'curvrankfinfindrhybriddorsal',
             'curvrankfluke',
+            'curvranktwodorsal',
+            'curvranktwofluke',
             'deepsense',
             'finfindr',
             'kaggle7',
             'kaggleseven',
             'pie',
+            'pietwo',
         ]
     ) and getattr(qreq_, '_isnewreq', None):
         if (
