@@ -92,6 +92,44 @@ def web_check_annot_uuids_with_names(annot_uuid_list, name_list):
     return annot_uuid_list_, name_list_
 
 
+@register_ibs_method
+@register_api('/api/engine/image/json/', methods=['POST', 'GET'])
+def start_add_images(
+    ibs,
+    image_uri_list,
+    callback_url=None,
+    callback_method=None,
+    callback_detailed=False,
+    lane='fast',
+    jobid=None,
+    **kwargs
+):
+    """
+    REST:
+        Method: GET/api/engine/image/json/
+        URL:
+
+    Args:
+        image_uri_list (list) : list of image urls to import.
+        callback_url (url) : url that will be called when detection succeeds or fails
+    """
+    assert len(image_uri_list) > 0, 'Cannot send a list of image_uri_list that is empty'
+
+    args = (image_uri_list,)
+    jobid = ibs.job_manager.jobiface.queue_job(
+        action='add_images_json',
+        callback_url=callback_url,
+        callback_method=callback_method,
+        callback_detailed=callback_detailed,
+        lane=lane,
+        jobid=jobid,
+        args=args,
+        kwargs=kwargs,
+    )
+
+    return jobid
+
+
 @register_ibs_method
 @register_api('/api/engine/uuid/check/', methods=['GET', 'POST'])
 def web_check_uuids(ibs, image_uuid_list=[], qannot_uuid_list=[], dannot_uuid_list=[]):
@@ -195,6 +233,7 @@ def start_identify_annots(
     pipecfg={},
     callback_url=None,
     callback_method=None,
+    callback_detailed=False,
     lane='slow',
     jobid=None,
 ):
@@ -323,7 +362,13 @@ def start_identify_annots(
     )
     args = (qaid_list, daid_list, pipecfg)
     jobid = ibs.job_manager.jobiface.queue_job(
-        'query_chips_simple_dict', callback_url, callback_method, lane, jobid, *args
+        action='query_chips_simple_dict',
+        callback_url=callback_url,
+        callback_method=callback_method,
+        callback_detailed=callback_detailed,
+        lane=lane,
+        jobid=jobid,
+        args=args,
     )
 
     # if callback_url is not None:
@@ -345,6 +390,7 @@ def start_identify_annots_query_complete(
     echo_query_params=True,
     callback_url=None,
     callback_method=None,
+    callback_detailed=False,
     lane='slow',
     jobid=None,
 ):
@@ -401,7 +447,13 @@ def start_identify_annots_query_complete(
         k,
     )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'query_chips_graph_complete', callback_url, callback_method, lane, jobid, *args
+        action='query_chips_graph_complete',
+        callback_url=callback_url,
+        callback_method=callback_method,
+        callback_detailed=callback_detailed,
+        lane=lane,
+        jobid=jobid,
+        args=args,
     )
     return jobid
 
@@ -423,6 +475,7 @@ def start_identify_annots_query(
     include_qaid_in_daids=True,
     callback_url=None,
     callback_method=None,
+    callback_detailed=False,
     lane='slow',
     jobid=None,
 ):
@@ -640,7 +693,13 @@ def start_identify_annots_query(
     )
     args = (qaid_list, daid_list, user_feedback, query_config_dict, echo_query_params)
     jobid = ibs.job_manager.jobiface.queue_job(
-        'query_chips_graph', callback_url, callback_method, lane, jobid, *args
+        action='query_chips_graph',
+        callback_url=callback_url,
+        callback_method=callback_method,
+        callback_detailed=callback_detailed,
+        lane=lane,
+        jobid=jobid,
+        args=args,
     )
     return jobid
 
@@ -652,6 +711,7 @@ def start_wic_image(
     image_uuid_list,
     callback_url=None,
     callback_method=None,
+    callback_detailed=False,
     lane='fast',
     jobid=None,
     **kwargs
@@ -678,7 +738,13 @@ def start_wic_image(
         kwargs,
     )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'wic_cnn_json', callback_url, callback_method, lane, jobid, *args
+        action='wic_cnn_json',
+        callback_url=callback_url,
+        callback_method=callback_method,
+        callback_detailed=callback_detailed,
+        lane=lane,
+        jobid=jobid,
+        args=args,
     )
 
     # if callback_url is not None:
@@ -695,6 +761,7 @@ def start_detect_image_yolo(
     image_uuid_list,
     callback_url=None,
     callback_method=None,
+    callback_detailed=False,
     lane='fast',
     jobid=None,
     **kwargs
@@ -721,7 +788,13 @@ def start_detect_image_yolo(
         kwargs,
     )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'detect_cnn_yolo_json', callback_url, callback_method, lane, jobid, *args
+        action='detect_cnn_yolo_json',
+        callback_url=callback_url,
+        callback_method=callback_method,
+        callback_detailed=callback_detailed,
+        lane=lane,
+        jobid=jobid,
+        args=args,
     )
 
     # if callback_url is not None:
@@ -738,6 +811,7 @@ def start_labeler_cnn(
     annot_uuid_list,
     callback_url=None,
     callback_method=None,
+    callback_detailed=False,
     lane='fast',
     jobid=None,
     **kwargs
@@ -756,7 +830,13 @@ def start_labeler_cnn(
         kwargs,
     )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'labeler_cnn', callback_url, callback_method, lane, jobid, *args
+        action='labeler_cnn',
+        callback_url=callback_url,
+        callback_method=callback_method,
+        callback_detailed=callback_detailed,
+        lane=lane,
+        jobid=jobid,
+        args=args,
     )
 
     # if callback_url is not None:
@@ -774,6 +854,7 @@ def start_review_query_chips_best(
     database_imgsetid=None,
     callback_url=None,
     callback_method=None,
+    callback_detailed=False,
     lane='slow',
     jobid=None,
     **kwargs
@@ -794,7 +875,13 @@ def start_review_query_chips_best(
         database_imgsetid,
     )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'review_query_chips_best', callback_url, callback_method, lane, jobid, *args
+        action='review_query_chips_best',
+        callback_url=callback_url,
+        callback_method=callback_method,
+        callback_detailed=callback_detailed,
+        lane=lane,
+        jobid=jobid,
+        args=args,
     )
 
     # if callback_url is not None:
@@ -838,7 +925,15 @@ def start_detect_image_lightnet(
         image_uuid_list (list) : list of image uuids or urls to detect on.
         callback_url (url) : url that will be called when detection succeeds or fails
     """
-    if image_uuid_list and '://' not in image_uuid_list[0]:
+    assert len(image_uuid_list) > 0, 'Cannot send a list of image_uuid_list that is empty'
+
+    image_uuid_types = list(set(list(map(type, image_uuid_list))))
+    if len(image_uuid_types) > 1:
+        raise ValueError('Cannot send a list of UUIDs mixed with URLs')
+    assert len(image_uuid_types) == 1
+    image_uuid_type = image_uuid_types[0]
+
+    if image_uuid_type == uuid.UUID:
         # Check UUIDs
         ibs.web_check_uuids(image_uuid_list=image_uuid_list)
 
@@ -852,13 +947,13 @@ def start_detect_image_lightnet(
             kwargs,
         )
         jobid = ibs.job_manager.jobiface.queue_job(
-            'detect_cnn_lightnet_json',
-            callback_url,
-            callback_method,
-            callback_detailed,
-            lane,
-            jobid,
-            *args
+            action='detect_cnn_lightnet_json',
+            callback_url=callback_url,
+            callback_method=callback_method,
+            callback_detailed=callback_detailed,
+            lane=lane,
+            jobid=jobid,
+            args=args,
         )
     else:
         # image_uuid_list contains urls
@@ -867,13 +962,13 @@ def start_detect_image_lightnet(
             kwargs,
         )
         jobid = ibs.job_manager.jobiface.queue_job(
-            'detect_cnn_lightnet_image_uris_json',
-            callback_url,
-            callback_method,
-            callback_detailed,
-            lane,
-            jobid,
-            *args
+            action='detect_cnn_lightnet_image_uris_json',
+            callback_url=callback_url,
+            callback_method=callback_method,
+            callback_detailed=callback_detailed,
+            lane=lane,
+            jobid=jobid,
+            args=args,
         )
 
     # if callback_url is not None:
@@ -903,6 +998,7 @@ def start_predict_ws_injury_interim_svm(
     annot_uuid_list,
     callback_url=None,
     callback_method=None,
+    callback_detailed=False,
     lane='fast',
     jobid=None,
     **kwargs
@@ -946,7 +1042,13 @@ def start_predict_ws_injury_interim_svm(
     annots = ibs.annots(uuids=annot_uuid_list)
     args = (annots.aids,)
     jobid = ibs.job_manager.jobiface.queue_job(
-        'predict_ws_injury_interim_svm', callback_url, callback_method, lane, jobid, *args
+        action='predict_ws_injury_interim_svm',
+        callback_url=callback_url,
+        callback_method=callback_method,
+        callback_detailed=callback_detailed,
+        lane=lane,
+        jobid=jobid,
+        args=args,
     )
 
     # if callback_url is not None:
@@ -964,7 +1066,9 @@ def start_web_query_all(ibs):
         Method: GET
         URL: /api/engine/query/web/
     """
-    jobid = ibs.job_manager.jobiface.queue_job('load_identification_query_object_worker')
+    jobid = ibs.job_manager.jobiface.queue_job(
+        action='load_identification_query_object_worker'
+    )
     return jobid
 
 
@@ -976,5 +1080,5 @@ def start_wildbook_sync(ibs, **kwargs):
         Method: GET
         URL: /api/engine/wildbook/sync/
     """
-    jobid = ibs.job_manager.jobiface.queue_job('wildbook_sync')
+    jobid = ibs.job_manager.jobiface.queue_job(action='wildbook_sync')
     return jobid
