@@ -19,7 +19,7 @@ import traceback
 import requests
 from datetime import datetime
 
-(print, rrr, profile) = ut.inject2(__name__)
+# (print, rrr, profile) = ut.inject2(__name__)
 logger = logging.getLogger('wbia')
 
 CLASS_INJECT_KEY, register_ibs_method = controller_inject.make_ibs_register_decorator(
@@ -32,6 +32,9 @@ register_route = controller_inject.get_wbia_flask_route(__name__)
 GRAPH_CLIENT_PEEK = 100
 
 
+RENDER_STATUS = None
+
+
 @register_ibs_method
 @register_api('/api/query/annot/rowid/', methods=['GET'])
 def get_recognition_query_aids(ibs, is_known, species=None):
@@ -278,8 +281,10 @@ def ensure_review_image(
 
         if hasattr(qreq_, 'render_single_result'):
             image = qreq_.render_single_result(cm, aid, **render_config)
-        else:
+        elif hasattr(cm, 'render_single_annotmatch'):
             image = cm.render_single_annotmatch(qreq_, aid, **render_config)
+        else:
+            image = ibs.get_annot_chips(aid)
         # image = vt.crop_out_imgfill(image, fillval=(255, 255, 255), thresh=64)
         cv2.imwrite(match_thumb_filepath, image)
     return image, match_thumb_filepath
@@ -837,11 +842,22 @@ def query_chips_graph_complete(ibs, aid_list, query_config_dict={}, k=5, **kwarg
 def log_render_status(ibs, *args):
     import os
 
+    global RENDER_STATUS
+
+    if RENDER_STATUS is None:
+        RENDER_STATUS = ibs._init_render_status()
+    assert RENDER_STATUS is not None
+
     json_log_path = ibs.get_logdir_local()
     json_log_filename = 'render.log'
     json_log_filepath = os.path.join(json_log_path, json_log_filename)
     logger.info('Logging renders added to: %r' % (json_log_filepath,))
 
+    status = '%s' % (args[-1],)
+    if status not in RENDER_STATUS:
+        RENDER_STATUS[status] = 0
+    RENDER_STATUS[status] += 1
+
     try:
         with open(json_log_filepath, 'a') as json_log_file:
             line = ','.join(['%s' % (arg,) for arg in args])
@@ -851,6 +867,32 @@ def log_render_status(ibs, *args):
         logger.info('WRITE RENDER.LOG FAILED')
 
 
+@register_ibs_method
+def _init_render_status(ibs):
+    import os
+
+    json_log_path = ibs.get_logdir_local()
+    json_log_filename = 'render.log'
+    json_log_filepath = os.path.join(json_log_path, json_log_filename)
+
+    status_dict = {}
+    try:
+        with open(json_log_filepath, 'r') as json_log_file:
+            for line in json_log_file.readlines():
+                try:
+                    line = line.strip().split(',')
+                    status = line[-1]
+                    if status not in status_dict:
+                        status_dict[status] = 0
+                    status_dict[status] += 1
+                except Exception:
+                    pass
+    except Exception:
+        pass
+
+    return status_dict
+
+
 @register_ibs_method
 @register_api('/api/query/graph/', methods=['GET', 'POST'])
 def query_chips_graph(
@@ -1049,11 +1091,13 @@ def query_chips_graph(
                             draw_matches=True,
                             draw_heatmask=False,
                         )
-                    except Exception:
+                    except Exception as ex:
                         filepath_matches = None
                         extern_flag = 'error'
+                        ut.printex(ex, iswarning=True)
                     log_render_status(
                         ibs,
+                        ut.timestamp(),
                         cm.qaid,
                         daid,
                         quuid,
@@ -1076,11 +1120,13 @@ def query_chips_graph(
                             draw_matches=False,
                             draw_heatmask=True,
                         )
-                    except Exception:
+                    except Exception as ex:
                         filepath_heatmask = None
                         extern_flag = 'error'
+                        ut.printex(ex, iswarning=True)
                     log_render_status(
                         ibs,
+                        ut.timestamp(),
                         cm.qaid,
                         daid,
                         quuid,
@@ -1103,11 +1149,13 @@ def query_chips_graph(
                             draw_matches=False,
                             draw_heatmask=False,
                         )
-                    except Exception:
+                    except Exception as ex:
                         filepath_clean = None
                         extern_flag = 'error'
+                        ut.printex(ex, iswarning=True)
                     log_render_status(
                         ibs,
+                        ut.timestamp(),
                         cm.qaid,
                         daid,
                         quuid,
