@@ -3,7 +3,7 @@
 Dependencies: flask, tornado
 
 SeeAlso:
-    routes.turk_identification
+    routes.review_identification
 """
 import logging
 from wbia.control import controller_inject
@@ -12,7 +12,6 @@ import numpy as np  # NOQA
 import utool as ut
 import uuid
 import requests
-import six
 import json
 
 (print, rrr, profile) = ut.inject2(__name__)
@@ -47,7 +46,7 @@ else:
         REMOTE_UUID = None
 
 
-REMOTE_URL = 'http://%s:%s' % (REMOTE_DOMAIN, REMOTE_PORT)
+REMOTE_URL = 'https://%s:%s' % (REMOTE_DOMAIN, REMOTE_PORT)
 REMOTE_UUID = None if REMOTE_UUID is None else uuid.UUID(REMOTE_UUID)
 
 
@@ -109,7 +108,7 @@ def _assert_remote_online(ibs):
         if REMOTE_UUID is not None:
             assert uuid == REMOTE_UUID
     except Exception:
-        raise IOError('Remote IBEIS DETECT database offline at %s' % (REMOTE_URL,))
+        raise IOError('Remote WBIA DETECT database offline at %s' % (REMOTE_URL,))
 
 
 @register_ibs_method
@@ -366,7 +365,9 @@ def sync_get_training_data(ibs, species_name, force_update=False, **kwargs):
     name_texts = ibs._sync_get_annot_endpoint('/api/annot/name/text/', aid_list)
     name_uuids = ibs._sync_get_annot_endpoint('/api/annot/name/uuid/', aid_list)
     images = ibs._sync_get_annot_endpoint('/api/annot/image/rowid/', aid_list)
-    gpaths = [ibs._construct_route_url_ibs('/api/image/src/%s/' % gid) for gid in images]
+    gpaths = [
+        ibs._construct_route_url_ibs('/api/image/src/%s.jpg' % gid) for gid in images
+    ]
     specieses = [species_name] * len(aid_list)
 
     gid_list = ibs.add_images(gpaths)
@@ -533,10 +534,7 @@ def detect_remote_sync_images(ibs, gid_list=None, only_sync_missing_images=True)
         % (confirm_str,)
     )
 
-    if six.PY2:
-        input_func = raw_input  # NOQA
-    else:
-        input_func = input
+    input_func = input
     response_str = input_func('Confirmation string [Empty to abort]: ')
     response_str = response_str.lower()
     assert confirm_str == response_str, 'Confirmation string mismatch, aborting...'
