@@ -446,14 +446,23 @@ def job_engine_tester():
         callback_url = None
         callback_method = None
         args = (1,)
-        jobid1 = jobiface.queue_job('helloworld', callback_url, callback_method, *args)
+        jobid1 = jobiface.queue_job(
+            action='helloworld',
+            callback_url=callback_url,
+            callback_method=callback_method,
+            args=args,
+        )
         jobiface.wait_for_job_result(jobid1)
         jobid_list = []
 
         args = ([1], [3, 4, 5])
         kwargs = dict(cfgdict={'K': 1})
         identify_jobid = jobiface.queue_job(
-            'query_chips_simple_dict', callback_url, callback_method, *args, **kwargs
+            action='query_chips_simple_dict',
+            callback_url=callback_url,
+            callback_method=callback_method,
+            args=args,
+            kwargs=kwargs,
         )
         for jobid in jobid_list:
             jobiface.wait_for_job_result(jobid)
@@ -671,6 +680,8 @@ def wait_for_shelve_lock_file(shelve_filepath, timeout=600):
 
 
 def get_shelve_value(shelve_filepath, key):
+    if shelve_filepath in [None, 'None', 'None.lock']:
+        return None
     wait_for_shelve_lock_file(shelve_filepath)
     with GLOBAL_SHELVE_LOCK:
         wait_for_shelve_lock_file(shelve_filepath)
@@ -686,6 +697,8 @@ def get_shelve_value(shelve_filepath, key):
 
 
 def set_shelve_value(shelve_filepath, key, value):
+    if shelve_filepath in [None, 'None', 'None.lock']:
+        return False
     wait_for_shelve_lock_file(shelve_filepath)
     with GLOBAL_SHELVE_LOCK:
         wait_for_shelve_lock_file(shelve_filepath)
@@ -717,7 +730,7 @@ def initialize_process_record(
     jobiface_id,
 ):
     MAX_ATTEMPTS = 20
-    ARCHIVE_DAYS = 14
+    ARCHIVE_DAYS = 3
 
     timezone = pytz.timezone(TIMESTAMP_TIMEZONE)
     now = datetime.now(timezone)
@@ -1033,8 +1046,8 @@ class JobInterface(object):
         callback_detailed=False,
         lane='slow',
         jobid=None,
-        *args,
-        **kwargs
+        args=None,
+        kwargs=None,
     ):
         r"""
         IBEIS:
@@ -1054,7 +1067,6 @@ class JobInterface(object):
         with ut.Indenter('[client %d] ' % (jobiface.id_)):
             if jobiface.verbose >= 1:
                 print('----')
-
             request = {}
             try:
                 if flask.request:
@@ -1066,6 +1078,12 @@ class JobInterface(object):
             except RuntimeError:
                 pass
 
+            if args is None:
+                args = tuple([])
+
+            if kwargs is None:
+                kwargs = {}
+
             if jobid is not None:
                 assert isinstance(jobid, str)
                 jobid_ = uuid.UUID(jobid)
@@ -1111,7 +1129,7 @@ class JobInterface(object):
                 }
                 ut.save_cPkl(record_filepath, record, verbose=False)
 
-            # Release memor
+            # Release memory
             action = None
             args = None
             kwargs = None
@@ -1356,7 +1374,7 @@ def engine_queue_loop(port_dict, engine_lanes):
                     kwargs = engine_request['kwargs']
                     callback_url = engine_request['callback_url']
                     callback_method = engine_request['callback_method']
-                    callback_detailed = engine_request['callback_detailed']
+                    callback_detailed = engine_request.get('callback_detailed', False)
                     request = engine_request['request']
                     restart_jobid = engine_request.get('restart_jobid', None)
                     restart_jobcounter = engine_request.get('restart_jobcounter', None)
@@ -1591,7 +1609,7 @@ def engine_loop(id_, port_dict, dbdir, containerized, lane):
                     kwargs = engine_request['kwargs']
                     callback_url = engine_request['callback_url']
                     callback_method = engine_request['callback_method']
-                    callback_detailed = engine_request['callback_detailed']
+                    callback_detailed = engine_request.get('callback_detailed', False)
                     lane_ = engine_request['lane']
 
                     if VERBOSE_JOBS:
@@ -1699,7 +1717,7 @@ def engine_loop(id_, port_dict, dbdir, containerized, lane):
 def on_engine_request(
     ibs, jobid, action, args, kwargs, attempts=3, retry_delay_min=1, retry_delay_max=60
 ):
-    """ Run whenever the engine recieves a message """
+    """Run whenever the engine recieves a message"""
     assert attempts > 0
     attempts = int(attempts)
 
@@ -1886,7 +1904,7 @@ def calculate_timedelta(start, end):
 def on_collect_request(
     ibs, collect_request, collector_data, shelve_path, containerized=False
 ):
-    """ Run whenever the collector recieves a message """
+    """Run whenever the collector recieves a message"""
     import requests
 
     action = collect_request.get('action', None)
@@ -1894,7 +1912,7 @@ def on_collect_request(
     status = collect_request.get('status', None)
 
     reply = {
-        'status': status,
+        'status': 'ok',
         'jobid': jobid,
     }
 
@@ -2084,11 +2102,13 @@ def on_collect_request(
 
             try:
                 data_dict = {'jobid': jobid}
+
                 if callback_detailed:
                     shelve_value = get_shelve_value(shelve_output_filepath, 'result')
                     data_dict['status'] = shelve_value['exec_status']
                     data_dict['json_result'] = ut.from_json(shelve_value['json_result'])
                     shelve_value = None  # Release memory
+
                 args = (
                     callback_url,
                     callback_method,
@@ -2262,7 +2282,7 @@ def on_collect_request(
 
 
 def send_multipart_json(sock, idents, reply):
-    """ helper """
+    """helper"""
     reply_json = ut.to_json(reply).encode('utf-8')
     reply = None
     multi_reply = idents + [reply_json]
@@ -2270,7 +2290,7 @@ def send_multipart_json(sock, idents, reply):
 
 
 def rcv_multipart_json(sock, num=2, print=print):
-    """ helper """
+    """helper"""
     # note that the first two parts will be ['Controller.ROUTER', 'Client.<id_>']
     # these are needed for the reply to propagate up to the right client
     multi_msg = sock.recv_multipart()
